PaymeParams class

Constructors

PaymeParams({required String? transactionParam, required String? merchantId, String accountObject = 'ac.order_id', Color headerColor = const Color(0xFF00CCCC), String headerTitle = "\"Payme\" to'lov tizimi"})

Properties

accountObject ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headerColor ↔ Color
getter/setter pair
headerTitle ↔ String
getter/setter pair
merchantId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transactionParam → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited